@@ -10,8 +10,11 @@ import {
   RoutePage,
   DevCatalogModel,
   DashboardsOverviewHealthOperator,
+  CatalogItemProvider,
+  CatalogItemType,
 } from '@console/plugin-sdk';
 import { referenceForModel } from '@console/internal/module/k8s';
+import { getExecutableCodeRef } from '@console/dynamic-plugin-sdk/src/coderefs/coderef-utils';
 import { FLAGS } from '@console/shared/src/constants';
 import { normalizeClusterServiceVersions } from './dev-catalog';
 import * as models from './models';
@@ -21,6 +24,12 @@ import { ClusterServiceVersionKind } from './types';
 
 import './style.scss';
 
+const catalogCSVProvider = getExecutableCodeRef(() =>
+  import('./utils/useClusterServiceVersions' /* webpackChunkName: "catalog-csv-provider" */).then(
+    (m) => m.default,
+  ),
+);
+
 type ConsumedExtensions =
   | ModelDefinition
   | ModelFeatureFlag
@@ -30,6 +39,8 @@ type ConsumedExtensions =
   | ResourceDetailsPage
   | RoutePage
   | DevCatalogModel
+  | CatalogItemProvider
+  | CatalogItemType
   | DashboardsOverviewHealthOperator<ClusterServiceVersionKind>;
 
 const plugin: Plugin<ConsumedExtensions> = [
@@ -50,16 +61,53 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'DevCatalogModel',
     properties: {
       model: models.ClusterServiceVersionModel,
-      flag: Flags.OPERATOR_LIFECYCLE_MANAGER,
       normalize: normalizeClusterServiceVersions,
     },
+    flags: {
+      required: [Flags.OPERATOR_LIFECYCLE_MANAGER],
+    },
+  },
+  {
+    type: 'Catalog/ItemType',
+    properties: {
+      type: 'OperatorBackedService',
+      // t('olm~Operator Backed')
+      title: '%olm~Operator Backed%',
+      // t('olm~Browse for a variety of managed services that are installed by cluster administrators. Cluster administrators can customize the content made available in the catalog.')
+      catalogDescription:
+        '%olm~Browse for a variety of managed services that are installed by cluster administrators. Cluster administrators can customize the content made available in the catalog.%',
+      // t('olm~**Operator backed** includes a variety of services managed by Kubernetes controllers.')
+      typeDescription:
+        '%olm~**Operator backed** includes a variety of services managed by Kubernetes controllers.%',
+      groupings: [
+        {
+          label: 'Operators',
+          attribute: 'operatorName',
+        },
+      ],
+    },
+    flags: {
+      required: [Flags.OPERATOR_LIFECYCLE_MANAGER],
+    },
+  },
+  {
+    type: 'Catalog/ItemProvider',
+    properties: {
+      type: 'OperatorBackedService',
+      provider: catalogCSVProvider,
+    },
+    flags: {
+      required: [Flags.OPERATOR_LIFECYCLE_MANAGER],
+    },
   },
   {
     type: 'NavItem/Href',
     properties: {
-      section: 'Operators',
+      id: 'operatorhub',
+      section: 'operators',
       componentProps: {
-        name: 'OperatorHub',
+        // t('olm~OperatorHub')
+        name: '%olm~OperatorHub%',
         href: '/operatorhub',
       },
     },
@@ -70,9 +118,11 @@ const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'NavItem/ResourceNS',
     properties: {
-      section: 'Operators',
+      id: 'operators',
+      section: 'operators',
       componentProps: {
-        name: 'Installed Operators',
+        // t('olm~Installed Operators')
+        name: '%olm~Installed Operators%',
         resource: referenceForModel(models.ClusterServiceVersionModel),
         startsWith: [
           models.ClusterServiceVersionModel.apiGroup,
@@ -157,6 +207,15 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).ClusterServiceVersionsPage,
     },
   },
+  {
+    type: 'Page/Resource/List',
+    properties: {
+      model: models.PackageManifestModel,
+      loader: async () =>
+        (await import('./components/package-manifest' /* webpackChunkName: "package-manifest" */))
+          .PackageManifestsPage,
+    },
+  },
   {
     type: 'Page/Resource/Details',
     properties: {
@@ -182,19 +241,6 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).CreateSubscriptionYAML,
     },
   },
-  {
-    type: 'Page/Route',
-    properties: {
-      exact: true,
-      path: `/k8s/ns/:ns/${models.ClusterServiceVersionModel.plural}/:appName/:plural/~new`,
-      loader: async () =>
-        (
-          await import(
-            './components/operand/create-operand' /* webpackChunkName: "create-operand" */
-          )
-        ).CreateOperandPage,
-    },
-  },
   {
     type: 'Page/Route',
     properties: {
@@ -255,6 +301,15 @@ const plugin: Plugin<ConsumedExtensions> = [
         (await import('./components/operator-hub/operator-hub-details')).OperatorHubDetailsPage,
     },
   },
+  {
+    type: 'Page/Resource/Details',
+    properties: {
+      model: models.CatalogSourceModel,
+      loader: async () =>
+        (await import('./components/catalog-source' /* webpackChunkName: "catalog-source" */))
+          .CatalogSourceDetailsPage,
+    },
+  },
   {
     type: 'Page/Route',
     properties: {
